Streams using NumPy Arrays
==========================

.. currentmodule:: sounddevice

.. topic:: Overview

   .. autosummary::
      :nosignatures:
   
      Stream
      InputStream
      OutputStream

.. autoclass:: Stream
   :members:
   :undoc-members:
   :inherited-members:

.. autoclass:: InputStream

.. autoclass:: OutputStream

